@@ -19,7 +19,14 @@ def read_parquet_path(path: Path, *, df_description: str = "dataframe", **kwargs
     :param df_description: Optional description of dataframe.
     :param kwargs: These are forwarded to `pl.read_parquet`.
     """
-    uri = path_to_uri(path)
+    return read_parquet_uri(path_to_uri(path), df_description=df_description, **kwargs)
+
+
+def read_parquet_uri(uri: str, *, df_description: str = "dataframe", **kwargs: Any) -> pl.DataFrame:
+    """Return a dataframe read from the given URI using `smart_open`, thereby supporting both local and S3 URIs.
+
+    `kwargs` are forwarded to `pd.read_parquet`.
+    """
     timer = Timer()
     read_description = f"{df_description} from {uri} using smart-open"
     log.debug(f"Reading {read_description}.")
